Download/upload
===============

This library supplies utility functions for file downloading and uploading.
The functions support automatic retries, multipart downloads and streaming
uploads. Their usage is described below.

Synchronous
-----------

.. automodule:: threedi_api_client.files
    :members: download_file, upload_file

    
Asynchronous
------------

.. automodule:: threedi_api_client.aio.files
    :members: download_file, upload_file
